==> ihaskell-0.12.0.0-106-loong64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-5llqVWRcywT89PKM2leTh
key:                  ihaskell-0.12.0.0-5llqVWRcywT89PKM2leTh
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  41e1aa7520e1d979792e24f7a76ee3cd
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-5llqVWRcywT89PKM2leTh
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-parser-0.2.7.0-BRTFlaUrolQBsJaOfBXbID
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-syntax-highlighter-0.0.10.0-BPbFMngeGvZBkfH3T0xhvk
    haskeline-0.8.2.1 hlint-3.6-AYkwZ12SFWNBJ4GT6RbrGu
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    ipython-kernel-0.11.0.0-KSTHHMXmY8mCgaUMOuN0el parsec-3.1.16.1
    process-1.6.19.0 random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    shelly-1.11.0-JmDpUTnbS08F8He1azDhqI
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    strict-0.5.1-Kvxonrthq62FwakQ5ElNMl text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ihaskell-0.12.0.0-107-loong64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-GTq496raG0JGMl5HdOZbf7
key:                  ihaskell-0.12.0.0-GTq496raG0JGMl5HdOZbf7
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  0efbc06b5cd2ea5945541097655c14d3
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-GTq496raG0JGMl5HdOZbf7
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-parser-0.2.7.0-BRTFlaUrolQBsJaOfBXbID
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-syntax-highlighter-0.0.10.0-3EIGG4OCzod6kPhwM8pZgw
    haskeline-0.8.2.1 hlint-3.6-8h1VjTRo2IgJGOdCbGdki6
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    ipython-kernel-0.11.0.0-JY887qs95p2K1HRIFm7l4W parsec-3.1.16.1
    process-1.6.19.0 random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    shelly-1.11.0-ILDqiDnnfQU5ZecPvyA3FE
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    strict-0.5.1-FbuUXvHHt04IVZ1UpYOqLR text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
